@@ -607,15 +607,15 @@ def find_variable(section, line, col) -> Optional[VarTokenInfo]:
                 token.type == token.ARGUMENT
                 and node.__class__.__name__ in CLASSES_WTH_EXPRESSION_ARGUMENTS
             ):
-                for part in iter_expression_variables(token):
+                for part, var_info in iter_expression_variables(token):
                     if part.type == token.VARIABLE:
                         if part.col_offset <= col <= part.end_col_offset:
                             return VarTokenInfo(
                                 stack,
                                 node,
                                 part,
-                                AdditionalVarInfo(
-                                    "$", AdditionalVarInfo.CONTEXT_EXPRESSION
+                                var_info.copy(
+                                    context=AdditionalVarInfo.CONTEXT_EXPRESSION
                                 ),
                             )
 
@@ -669,16 +669,18 @@ def tokenize_variables_from_name(name):
 
 def tokenize_variables(token: IRobotToken) -> Iterator[IRobotToken]:
     # May throw error if it's not OK.
-    return token.tokenize_variables()
+    return iter(tuple(token.tokenize_variables()))
 
 
-def _tokenize_variables_even_when_invalid(token: IRobotToken, col: int):
+def _tokenize_variables_even_when_invalid(
+    token: IRobotToken, col: int
+) -> Iterator[IRobotToken]:
     """
     If Token.tokenize_variables() fails, this can still provide the variable under
     the given column by applying some heuristics to find open variables.
     """
     try:
-        return tokenize_variables(token)
+        return iter(tuple(tokenize_variables(token)))
     except:
         pass
 
@@ -706,15 +708,18 @@ def _tokenize_variables_even_when_invalid(token: IRobotToken, col: int):
                     break
                 varname.append(c)
 
-            return [
-                Token(
-                    type=token.VARIABLE,
-                    value="".join(varname),
-                    lineno=token.lineno,
-                    col_offset=token.col_offset + open_at - 1,
-                    error=token.error,
-                )
-            ]
+            return iter(
+                [
+                    Token(
+                        type=token.VARIABLE,
+                        value="".join(varname),
+                        lineno=token.lineno,
+                        col_offset=token.col_offset + open_at - 1,
+                        error=token.error,
+                    )
+                ]
+            )
+    return iter(())
 
 
 LIBRARY_IMPORT_CLASSES = ("LibraryImport",)
@@ -1240,13 +1245,11 @@ def iter_variable_references(ast) -> Iterator[VarTokenInfo]:
 
                         next_tok_type = keyword_usage_handler.get_token_type(token)
                         if next_tok_type == keyword_usage_handler.EXPRESSION:
-                            for tok in iter_expression_variables(token):
+                            for tok, var_info in iter_expression_variables(token):
                                 if tok.type == token.VARIABLE:
                                     if not _add_match(found, tok):
                                         continue
-                                    yield VarTokenInfo(
-                                        stack, node, tok, AdditionalVarInfo("$")
-                                    )
+                                    yield VarTokenInfo(stack, node, tok, var_info)
 
     for clsname in CLASSES_WTH_EXPRESSION_ARGUMENTS:
         for node_info in ast.iter_indexed(clsname):
@@ -1257,13 +1260,11 @@ def iter_variable_references(ast) -> Iterator[VarTokenInfo]:
             for token in node.tokens:
                 try:
                     if token.type == token.ARGUMENT:
-                        for tok in iter_expression_variables(token):
+                        for tok, var_info in iter_expression_variables(token):
                             if tok.type == token.VARIABLE:
                                 if not _add_match(found, tok):
                                     continue
-                                yield VarTokenInfo(
-                                    stack, node, tok, AdditionalVarInfo("$")
-                                )
+                                yield VarTokenInfo(stack, node, tok, var_info)
                 except:
                     log.exception("Unable to tokenize: %s", token)
 
@@ -1381,7 +1382,7 @@ def get_keyword_name_token(
         token.type == token.NAME
         and node.__class__.__name__ in CLASSES_WITH_ARGUMENTS_AS_KEYWORD_CALLS_AS_SET
     ):
-        return _strip_token_bdd_prefix(token)
+        return _strip_token_bdd_prefix(token)[1]
 
     if token.type == token.ARGUMENT and not token.value.strip().endswith("}"):
         from robotframework_ls.impl.ast_utils_keyword_usage import (
@@ -1456,7 +1457,9 @@ def _copy_of_node_replacing_token(node, token, token_type):
     return node.__class__(new_tokens)
 
 
-def _strip_node_and_token_bdd_prefix(node, token_type):
+def _strip_node_and_token_bdd_prefix(
+    node: INode, token_type: str
+) -> Tuple[str, INode, Optional[IRobotToken]]:
     """
     This is a workaround because the parsing does not separate a BDD prefix from
     the keyword name. If the parsing is improved to do that separation in the future
@@ -1464,41 +1467,40 @@ def _strip_node_and_token_bdd_prefix(node, token_type):
     """
     original_token = node.get_token(token_type)
     if original_token is None:
-        return node, None
-    token = _strip_token_bdd_prefix(original_token)
+        return "", node, None
+    prefix, token = _strip_token_bdd_prefix(original_token)
     if token is original_token:
         # i.e.: No change was done.
-        return node, token
-    return _copy_of_node_replacing_token(node, token, token_type), token
+        return prefix, node, token
+    return prefix, _copy_of_node_replacing_token(node, token, token_type), token
 
 
-def _strip_token_bdd_prefix(token):
+def _strip_token_bdd_prefix(token: IRobotToken) -> Tuple[str, IRobotToken]:
     """
     This is a workaround because the parsing does not separate a BDD prefix from
     the keyword name. If the parsing is improved to do that separation in the future
     we can stop doing this.
 
-    :return Token:
-        Returns a new token with the bdd prefix stripped or the original token passed.
+    :return: the prefix and a new token with the bdd prefix stripped or the
+    original token passed (if no prefix was detected).
     """
     from robotframework_ls.impl.robot_constants import BDD_PREFIXES
     from robot.api import Token
 
-    if token is None:
-        return token
+    assert token is not None
 
     text = token.value.lower()
     for prefix in BDD_PREFIXES:
         if text.startswith(prefix):
             new_name = token.value[len(prefix) :]
-            return Token(
+            return prefix, Token(
                 type=token.type,
                 value=new_name,
                 lineno=token.lineno,
                 col_offset=token.col_offset + len(prefix),
                 error=token.error,
             )
-    return token
+    return "", token
 
 
 def _append_eol_to_prev_token(last_token, eol_token_contents):
@@ -1778,12 +1780,14 @@ def get_library_arguments_serialized(library) -> Optional[str]:
     return "::".join(library.args) if library.args else None
 
 
-def iter_expression_variables(expression_token: IRobotToken) -> Iterator[IRobotToken]:
+def iter_expression_variables(
+    expression_token: IRobotToken,
+) -> Iterator[Tuple[IRobotToken, AdditionalVarInfo]]:
     from robot.api import Token
 
-    for tok, _var_info in iter_expression_tokens(expression_token):
+    for tok, var_info in iter_expression_tokens(expression_token):
         if tok.type == Token.VARIABLE:
-            yield tok
+            yield tok, var_info
 
 
 class RobotMatchTokensGenerator:
