@@ -11,7 +11,7 @@ from robotframework_ls.impl.protocols import (
     LibraryDependencyInfo,
     AbstractKeywordCollector,
 )
-from typing import Sequence, List, Dict, Optional, Iterator
+from typing import Sequence, List, Dict, Optional, Iterator, Any
 from robotframework_ls.impl.text_utilities import build_keyword_docs_with_signature
 from robocorp_ls_core.lsp import MarkupContentTypedDict, MarkupKind
 
@@ -320,6 +320,7 @@ def _collect_libraries_keywords(
     completion_context: ICompletionContext,
     library_infos: Iterator[LibraryDependencyInfo],
     collector: IKeywordCollector,
+    memo: Dict[Any, Any],
 ):
     from robotframework_ls.impl.libspec_manager import LibspecManager
     from robotframework_ls.impl.protocols import ILibraryDocOrError
@@ -342,7 +343,19 @@ def _collect_libraries_keywords(
             )
         )
         library_doc = library_doc_or_error.library_doc
+
         if library_doc is not None:
+            key: Any = library_doc.source
+            if not key:
+                key = library_doc
+            key = (key, library_info.alias)
+
+            visited = memo.get(key, False)
+            if visited:
+                continue
+            else:
+                memo[key] = True
+
             #: :type keyword: KeywordDoc
             for keyword in library_doc.keywords:
                 keyword_name = keyword.name
@@ -380,13 +393,13 @@ def _collect_libraries_keywords(
 
                 if node_name_tok is not None:
                     (
-                        _value,
+                        value,
                         token_errors,
                     ) = completion_context.token_value_and_unresolved_resolving_variables(
                         node_name_tok
                     )
                     if token_errors:
-                        for token_error in token_errors:
+                        for token_error, error_msg in token_errors:
                             collector.on_unresolved_library(
                                 completion_context,
                                 node.name,
@@ -394,7 +407,8 @@ def _collect_libraries_keywords(
                                 token_error.lineno,
                                 token_error.col_offset,
                                 token_error.end_col_offset,
-                                f"\nUnable to statically resolve variable: {token_error.value}.\nPlease set the `{token_error.value[2:-1]}` value in `robot.variables`.",
+                                error_msg,
+                                value,
                             )
                     else:
                         collector.on_unresolved_library(
@@ -405,6 +419,7 @@ def _collect_libraries_keywords(
                             node_name_tok.col_offset,
                             node_name_tok.end_col_offset,
                             error_msg,
+                            value,
                         )
                 else:
                     collector.on_unresolved_library(
@@ -415,6 +430,7 @@ def _collect_libraries_keywords(
                         node.col_offset,
                         node.end_col_offset,
                         error_msg,
+                        "",
                     )
 
 
@@ -428,10 +444,12 @@ def _collect_from_context(
     _collect_current_doc_keywords(completion_context, collector)
 
     completion_context.check_cancelled()
+    memo: Dict[Any, Any] = {}
     _collect_libraries_keywords(
         completion_context,
         dependency_graph.iter_libraries(completion_context.doc.uri),
         collector,
+        memo,
     )
 
     for node, resource_doc in dependency_graph.iter_all_resource_imports_with_docs():
@@ -447,14 +465,14 @@ def _collect_from_context(
             if node_name_tok is not None:
 
                 (
-                    _value,
+                    value,
                     token_errors,
                 ) = completion_context.token_value_and_unresolved_resolving_variables(
                     node_name_tok
                 )
 
                 if token_errors:
-                    for token_error in token_errors:
+                    for token_error, error_msg in token_errors:
                         collector.on_unresolved_resource(
                             completion_context,
                             node.name,
@@ -462,7 +480,8 @@ def _collect_from_context(
                             token_error.lineno,
                             token_error.col_offset,
                             token_error.end_col_offset,
-                            f"\nUnable to statically resolve variable: {token_error.value}.\nPlease set the `{token_error.value[2:-1]}` value in `robot.variables`.",
+                            error_msg,
+                            value,
                         )
 
                 else:
@@ -474,6 +493,7 @@ def _collect_from_context(
                         node_name_tok.col_offset,
                         node_name_tok.end_col_offset,
                         None,
+                        value,
                     )
             else:
                 collector.on_unresolved_resource(
@@ -484,6 +504,7 @@ def _collect_from_context(
                     node.col_offset,
                     node.end_col_offset,
                     None,
+                    "",
                 )
             continue
         completion_context.check_cancelled()
@@ -494,6 +515,7 @@ def _collect_from_context(
             new_ctx,
             dependency_graph.iter_libraries(resource_doc.uri),
             collector,
+            memo,
         )
 
 
