@@ -239,6 +239,15 @@ class AdditionalVarInfo:
         self.context = context
         self.extended_part = extended_part
 
+    def copy(self, **kwargs):
+        new_kwargs = {
+            "var_identifier": self.var_identifier,
+            "context": self.context,
+            "extended_part": self.extended_part,
+        }
+        new_kwargs.update(kwargs)
+        return AdditionalVarInfo(**new_kwargs)
+
     def __str__(self):
         info = [f"AdditionalVarInfo({self.var_identifier}"]
         if self.context:
@@ -274,13 +283,7 @@ class VarTokenInfo:
 
 
 class KeywordUsageInfo:
-    __slots__ = [
-        "stack",
-        "node",
-        "token",
-        "name",
-        "_is_argument_usage",
-    ]
+    __slots__ = ["stack", "node", "token", "name", "_is_argument_usage", "prefix"]
 
     def __init__(
         self,
@@ -289,12 +292,14 @@ class KeywordUsageInfo:
         token: IRobotToken,
         name: str,
         is_argument_usage: bool = False,
+        prefix: str = "",
     ):
         self.stack = stack
         self.node = node
         self.token = token  # This is actually the keyword name token.
         self.name = name
         self._is_argument_usage = is_argument_usage
+        self.prefix = prefix
 
     def __repr__(self):
         if self._is_argument_usage:
@@ -620,6 +625,7 @@ class IKeywordCollector(Protocol):
         col_offset: int,
         end_col_offset: int,
         error_msg: Optional[str],
+        resolved_name: str,
     ):
         pass
 
@@ -632,6 +638,7 @@ class IKeywordCollector(Protocol):
         col_offset: int,
         end_col_offset: int,
         error_msg: Optional[str],
+        resolved_name: str,
     ):
         pass
 
@@ -654,6 +661,7 @@ class AbstractKeywordCollector:
         col_offset: int,
         end_col_offset: int,
         error_msg: Optional[str],
+        resolved_name: str,
     ):
         pass
 
@@ -666,6 +674,7 @@ class AbstractKeywordCollector:
         col_offset: int,
         end_col_offset: int,
         error_msg: Optional[str],
+        resolved_name: str,
     ):
         pass
 
@@ -992,7 +1001,9 @@ class ICompletionContext(Protocol):
         Provides the current variable token. Note that it won't include '{' nor '}'.
         """
 
-    def get_resource_import_as_doc(self, resource_import) -> Optional[IRobotDocument]:
+    def get_resource_import_as_doc(
+        self, resource_import: INode, check_as_module: bool = False
+    ) -> Optional[IRobotDocument]:
         pass
 
     def get_variable_imports(self) -> Tuple[INode, ...]:
@@ -1030,7 +1041,7 @@ class ICompletionContext(Protocol):
 
     def token_value_and_unresolved_resolving_variables(
         self, token: IRobotToken
-    ) -> Tuple[str, Tuple[IRobotToken, ...]]:
+    ) -> Tuple[str, Tuple[Tuple[IRobotToken, str], ...]]:
         pass
 
     def get_current_keyword_definition_and_usage_info(
@@ -1164,6 +1175,7 @@ class IVariablesCollector(Protocol):
         col_offset: int,
         end_col_offset: int,
         error_msg: Optional[str],
+        resolved_name: str,
     ):
         pass
 
@@ -1189,6 +1201,7 @@ class AbstractVariablesCollector:
         col_offset: int,
         end_col_offset: int,
         error_msg: Optional[str],
+        resolved_name: str,
     ):
         pass
 
