@@ -11,7 +11,13 @@ VARIABLE_PREFIXES = ("@", "%", "$", "&")
 ROBOT_FILE_EXTENSIONS = (".robot", ".resource")
 ROBOT_AND_TXT_FILE_EXTENSIONS = ROBOT_FILE_EXTENSIONS + (".txt",)
 LIBRARY_FILE_EXTENSIONS = (".py",)
-ALL_RELATED_FILE_EXTENSIONS = ROBOT_AND_TXT_FILE_EXTENSIONS + LIBRARY_FILE_EXTENSIONS
+
+# Extensions which may have keywords
+ALL_KEYWORD_RELATED_FILE_EXTENSIONS = (
+    ROBOT_AND_TXT_FILE_EXTENSIONS + LIBRARY_FILE_EXTENSIONS
+)
+
+VARIABLE_FILE_EXTENSIONS = (".yaml", ".yml")
 
 # From: robot.variables.scopes.GlobalVariables._set_built_in_variables
 # (var name and description)
@@ -211,6 +217,7 @@ STDLIBS = frozenset(
     )
 )
 
+STDLIBS_LOWER = frozenset(x.lower() for x in STDLIBS)
 
 ## Token types gotten from: robot.parsing.lexer.tokens.Token
 
@@ -218,6 +225,7 @@ STDLIBS = frozenset(
 SETTING_HEADER = "SETTING HEADER"
 VARIABLE_HEADER = "VARIABLE HEADER"
 TESTCASE_HEADER = "TESTCASE HEADER"
+TASK_HEADER = "TASK HEADER"  # Only available in RF 5.1
 KEYWORD_HEADER = "KEYWORD HEADER"
 COMMENT_HEADER = "COMMENT HEADER"
 
@@ -304,7 +312,14 @@ SETTING_TOKENS = frozenset(
     )
 )
 HEADER_TOKENS = frozenset(
-    (SETTING_HEADER, VARIABLE_HEADER, TESTCASE_HEADER, KEYWORD_HEADER, COMMENT_HEADER)
+    (
+        SETTING_HEADER,
+        VARIABLE_HEADER,
+        TESTCASE_HEADER,
+        TASK_HEADER,
+        KEYWORD_HEADER,
+        COMMENT_HEADER,
+    )
 )
 ALLOW_VARIABLES = frozenset((NAME, ARGUMENT, TESTCASE_NAME, KEYWORD_NAME))
 CONTROL_TOKENS = frozenset(
