@@ -1,3 +1,7 @@
+# Note: there's a copy of these settings at:
+# robotframework_interactive.server.rf_interpreter_ls_config
+# which should be kept up-to-date with this one.
+
 from typing import List
 
 OPTION_ROBOT_PYTHON_EXECUTABLE = "robot.python.executable"
@@ -11,6 +15,8 @@ OPTION_ROBOT_LANGUAGE_SERVER_ARGS = "robot.language-server.args"
 OPTION_ROBOT_VARIABLES = "robot.variables"
 OPTION_ROBOT_VARIABLES_LOAD_FROM_ARGUMENTS_FILE = "robot.loadVariablesFromArgumentsFile"
 
+OPTION_ROBOT_INTERACTIVE_CONSOLE_ARGUMENTS = "robot.interactiveConsole.arguments"
+
 OPTION_ROBOT_LINT_ROBOCOP_ENABLED = "robot.lint.robocop.enabled"
 
 OPTION_ROBOT_LINT_ENABLED = "robot.lint.enabled"
@@ -19,6 +25,9 @@ OPTION_ROBOT_LINT_UNDEFINED_LIBRARIES = "robot.lint.undefinedLibraries"
 OPTION_ROBOT_LINT_UNDEFINED_RESOURCES = "robot.lint.undefinedResources"
 OPTION_ROBOT_LINT_UNDEFINED_VARIABLE_IMPORTS = "robot.lint.undefinedVariableImports"
 OPTION_ROBOT_LINT_KEYWORD_CALL_ARGUMENTS = "robot.lint.keywordCallArguments"
+OPTION_ROBOT_LINT_KEYWORD_RESOLVES_TO_MULTIPLE_KEYWORDS = (
+    "robot.lint.keywordResolvesToMultipleKeywords"
+)
 
 OPTION_ROBOT_LINT_VARIABLES = "robot.lint.variables"
 OPTION_ROBOT_LINT_IGNORE_VARIABLES = "robot.lint.ignoreVariables"
@@ -52,6 +61,10 @@ OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM_BOTH = "both"
 
 OPTION_ROBOT_SHOW_CODE_LENSES = "robot.codeLens.enable"
 
+OPTION_ROBOT_COMPLETION_KEYWORDS_ARGUMENTS_SEPARATOR = (
+    "robot.completions.keywords.argumentsSeparator"
+)
+
 # Options which must be set as environment variables.
 ENV_OPTION_ROBOT_DAP_TIMEOUT = "ROBOT_DAP_TIMEOUT"
 
