@@ -291,14 +291,14 @@ def collect_global_variables_from_document_dependencies(
             if node_name_tok is not None:
 
                 (
-                    _value,
+                    value,
                     token_errors,
                 ) = completion_context.token_value_and_unresolved_resolving_variables(
                     node_name_tok
                 )
 
                 if token_errors:
-                    for token_error in token_errors:
+                    for token_error, error_msg in token_errors:
                         collector.on_unresolved_variable_import(
                             completion_context,
                             node.name,
@@ -306,7 +306,8 @@ def collect_global_variables_from_document_dependencies(
                             token_error.lineno,
                             token_error.col_offset,
                             token_error.end_col_offset,
-                            f"\nUnable to statically resolve variable: {token_error.value}.\nPlease set the `{token_error.value[2:-1]}` value in `robot.variables`.",
+                            error_msg,
+                            value,
                         )
 
                 else:
@@ -318,6 +319,7 @@ def collect_global_variables_from_document_dependencies(
                         node_name_tok.col_offset,
                         node_name_tok.end_col_offset,
                         None,
+                        value,
                     )
             else:
                 collector.on_unresolved_variable_import(
@@ -328,6 +330,7 @@ def collect_global_variables_from_document_dependencies(
                     node.col_offset,
                     node.end_col_offset,
                     None,
+                    "",
                 )
             continue
         _collect_variables_from_variable_import_doc(variable_doc, collector)
@@ -456,6 +459,10 @@ def collect_local_variables(
         completion_context.check_cancelled()
         if collector.accepts(assign_node_info.token.value):
             rep = " ".join(tok.value for tok in assign_node_info.node.tokens)
+            if assign_node_info.node.__class__.__name__ == "KeywordCall":
+                if assign_node_info.token.lineno == token_info.token.lineno:
+                    if not assign_node_info.node.keyword:
+                        continue  # Skip the definition we're currently on.
             variable_found = VariableFoundFromToken(
                 completion_context,
                 assign_node_info.token,
