@@ -7,7 +7,6 @@ from robocorp_ls_core.protocols import (
     IMonitor,
     ITestInfoTypedDict,
     IWorkspace,
-    ActionResultDict,
 )
 from functools import partial
 from robocorp_ls_core.jsonrpc.endpoint import require_monitor
@@ -23,7 +22,6 @@ from robocorp_ls_core.lsp import (
     DocumentHighlightTypedDict,
     RangeTypedDict,
     CompletionItemTypedDict,
-    ResponseTypedDict,
     WorkspaceEditTypedDict,
     SelectionRangeTypedDict,
 )
@@ -1202,3 +1200,12 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         workspace = self._workspace
         if workspace is not None:
             workspace.dispose()
+
+    def m_cancel_progress(self, progressId):
+        from robocorp_ls_core import progress_report
+
+        if progress_report.cancel(progressId):
+            log.info("Cancel progress %s", progressId)
+            return True
+
+        return False
