@@ -17,6 +17,7 @@ from timeit import default_timer as timer
 
 import robocop.exceptions
 from robocop.rules import Message
+from robocop.version import __version__
 
 
 class Report:
@@ -205,3 +206,25 @@ class FileStatsReport(Report):
             f"\nProcessed {self.files_count} file{plural_files} from which {len(self.files_with_issues)} "
             f"file{plural_files_with_issues} contained issues."
         )
+
+
+class RobocopVersionReport(Report):
+    """
+    Report name: ``version``
+
+    Report that returns Robocop version.
+
+    Example::
+
+        Report generated by Robocop version: 2.0.2
+    """
+
+    def __init__(self):
+        self.name = "version"
+        self.description = "Returns Robocop version"
+
+    def add_message(self, *args):
+        pass
+
+    def get_report(self) -> str:
+        return f"\nReport generated by Robocop version: {__version__}"
