@@ -62,7 +62,7 @@ class RuleSeverity(Enum):
     ERROR = "E"
 
     @classmethod
-    def parser(cls, value: Union[str, "RuleSeverity"]) -> "RuleSeverity":
+    def parser(cls, value: Union[str, "RuleSeverity"], rule_severity=True) -> "RuleSeverity":
         # parser can be invoked from Rule() with severity=RuleSeverity.WARNING (enum directly) or
         # from configuration with severity:W (string representation)
         severity = {
@@ -74,7 +74,15 @@ class RuleSeverity(Enum):
             "i": cls.INFO,
         }.get(str(value).lower(), None)
         if severity is None:
-            raise ValueError(f"Chose one of: {', '.join(sev.value for sev in cls)}") from None
+            severity_values = ", ".join(sev.value for sev in cls)
+            hint = f"Choose one from: {severity_values}."
+            if rule_severity:
+                # it will be reraised as RuleParamFailedInitError
+                raise ValueError(hint)
+            # invalid severity threshold
+            raise robocop.exceptions.InvalidArgumentError(
+                f"Invalid severity value '{value}'. {hint}"
+            ) from None
         return severity
 
     def __str__(self):
