@@ -12,6 +12,7 @@ from typing import (
     Type,
     Iterable,
     Tuple,
+    Sequence,
 )
 from typing import TypeVar
 import typing
@@ -138,6 +139,10 @@ class IEndPoint(Protocol):
 
 
 class IProgressReporter(Protocol):
+    @property
+    def cancelled(self) -> bool:
+        pass
+
     def set_additional_info(self, additional_info: str) -> None:
         """
         The progress reporter shows the title and elapsed time automatically.
@@ -238,7 +243,7 @@ class ILanguageServerClientBase(IRequestCancellable, Protocol):
         """
 
     def obtain_pattern_message_matcher(
-        self, message_pattern: Dict[str, str]
+        self, message_pattern: Dict[str, str], remove_on_match: bool = True
     ) -> IMessageMatcher:
         """
         Can be used as:
@@ -857,6 +862,22 @@ class ActionResult(Generic[T]):
     __repr__ = __str__
 
 
+class RCCActionResult(ActionResult[str]):
+
+    # A string-representation of the command line.
+    command_line: str
+
+    def __init__(
+        self,
+        command_line: str,
+        success: bool,
+        message: Optional[str] = None,
+        result: Optional[str] = None,
+    ):
+        ActionResult.__init__(self, success, message, result)
+        self.command_line = command_line
+
+
 class EnvEntry(TypedDict):
     key: str
     value: str
